@@ -50,6 +50,11 @@ if (read_config_option('auth_method') == '2') {
 		auth_display_custom_error_message(__('Web Basic Authentication configured, but no username was passed from the web server. Please make sure you have authentication enabled on the web server.'));
 		exit;
 	}
+
+	if (strpos($username, '@') !== false) {
+		$upart = explode('@', $username);
+		$username = $upart[0];
+	}
 } else {
 	if (get_nfilter_request_var('action') == 'login') {
 		/* LDAP and Builtin get username from Form */
@@ -119,7 +124,7 @@ if (get_nfilter_request_var('action') == 'login') {
 		/* LDAP Auth */
  		if ($frv_realm == '2' && get_nfilter_request_var('login_password') != '') {
 			/* include LDAP lib */
-			include_once('./lib/ldap.php');
+			include_once(__DIR__ . '/lib/ldap.php');
 
 			/* get user DN */
 			$ldap_dn_search_response = cacti_ldap_search_dn($username);
@@ -444,7 +449,7 @@ function domains_login_process() {
 
 	if (is_numeric(get_nfilter_request_var('realm')) && get_nfilter_request_var('login_password') != '') {
 		/* include LDAP lib */
-		include_once('./lib/ldap.php');
+		include_once(__DIR__ . '/lib/ldap.php');
 
 		/* get user DN */
 		$ldap_dn_search_response = domains_ldap_search_dn($username, get_nfilter_request_var('realm'));
@@ -668,7 +673,7 @@ $selectedTheme = get_selected_theme();
 	<div class='loginArea'>
 		<div class='cactiLoginLogo'></div>
 			<legend><?php print __('User Login');?></legend>
-			<form name='login' method='post' action='<?php print get_current_page();?>'>
+			<form id='login' name='login' method='post' action='<?php print get_current_page();?>'>
 				<input type='hidden' name='action' value='login'>
 				<?php api_plugin_hook_function('login_before',
 					array(
@@ -787,6 +792,6 @@ $selectedTheme = get_selected_theme();
 <?php } ?>
 	});
 	</script>
-	<?php include_once(dirname(__FILE__) . '/include/global_session.php');?>
+	<?php include_once(__DIR__ . '/include/global_session.php');?>
 </body>
 </html>
