@@ -123,19 +123,38 @@ function form_save() {
 		$save3['local_data_id']         = 0;
 
 		$save3['t_rrd_maximum']         = form_input_validate((isset_request_var('t_rrd_maximum') ? get_nfilter_request_var('t_rrd_maximum') : ''), 't_rrd_maximum', '', true, 3);
+
 		$save3['rrd_maximum']           = form_input_validate(get_nfilter_request_var('rrd_maximum'), 'rrd_maximum', '^(-?([0-9]+(\.[0-9]*)?|[0-9]*\.[0-9]+)([eE][+\-]?[0-9]+)?)|U$', (isset_request_var('t_rrd_maximum') ? true : false), 3);
+
 		$save3['t_rrd_minimum']         = form_input_validate((isset_request_var('t_rrd_minimum') ? get_nfilter_request_var('t_rrd_minimum') : ''), 't_rrd_minimum', '', true, 3);
+
 		$save3['rrd_minimum']           = form_input_validate(get_nfilter_request_var('rrd_minimum'), 'rrd_minimum', '^(-?([0-9]+(\.[0-9]*)?|[0-9]*\.[0-9]+)([eE][+\-]?[0-9]+)?)|U$', (isset_request_var('t_rrd_minimum') ? true : false), 3);
 
 		$save3['rrd_heartbeat']         = $rrd_heartbeat;
 
 		$save3['t_data_source_type_id'] = form_input_validate((isset_request_var('t_data_source_type_id') ? get_nfilter_request_var('t_data_source_type_id') : ''), 't_data_source_type_id', '', true, 3);
+
 		$save3['data_source_type_id']   = form_input_validate(get_request_var('data_source_type_id'), 'data_source_type_id', '^[0-9]+$', true, 3);
+
 		$save3['t_data_source_name']    = form_input_validate((isset_request_var('t_data_source_name') ? get_nfilter_request_var('t_data_source_name') : ''), 't_data_source_name', '', true, 3);
+
 		$save3['data_source_name']      = form_input_validate(get_nfilter_request_var('data_source_name'), 'data_source_name', '^[a-zA-Z0-9_]{1,19}$', (isset_request_var('t_data_source_name') ? true : false), 3);
+
 		$save3['t_data_input_field_id'] = form_input_validate((isset_request_var('t_data_input_field_id') ? get_nfilter_request_var('t_data_input_field_id') : ''), 't_data_input_field_id', '', true, 3);
+
 		$save3['data_input_field_id']   = form_input_validate((isset_request_var('data_input_field_id') ? get_nfilter_request_var('data_input_field_id') : '0'), 'data_input_field_id', '', true, 3);
 
+		if ($save3['rrd_minimum'] != 'U' && $save3['rrd_maximum'] != 'U') {
+			if ($save3['rrd_minimum'] >= $save3['rrd_maximum']) {
+				raise_message(43);
+
+				$_SESSION['sess_error_fields']['rrd_maximum'] = 'rrd_maximum';
+
+				header('Location: data_templates.php?header=false&action=template_edit&id=' . (empty($data_template_id) ? get_request_var('data_template_id') : $data_template_id) . (isempty_request_var('current_rrd') ? '' : '&view_rrd=' . (get_nfilter_request_var('current_rrd') ? get_nfilter_request_var('current_rrd') : get_request_var('data_template_rrd_id'))));
+				exit;
+			}
+		}
+
 		/* ok, first pull out all 'input' values so we know how much to save */
 		$input_fields = db_fetch_assoc_prepared("SELECT id, input_output, regexp_match,
 			allow_nulls, type_code, data_name
@@ -468,7 +487,7 @@ function template_rrd_add() {
 
 	db_execute_prepared('INSERT IGNORE INTO data_template_rrd
 		(hash, data_template_id, rrd_maximum, rrd_minimum, rrd_heartbeat, data_source_type_id, data_source_name)
-	    VALUES (?, ?, 0, 0, 600, 1, ?)', array($hash, get_request_var('id'), $dsname));
+	    VALUES (?, ?, "U", 0, 600, 1, ?)', array($hash, get_request_var('id'), $dsname));
 
 	$data_template_rrd_id = db_fetch_insert_id();
 
@@ -652,7 +671,16 @@ function template_edit() {
 		}
 	}
 
-	if (!$isSNMPget) {
+	if (get_request_var('id') > 0) {
+		$readOnly = db_fetch_cell_prepared('SELECT *
+			FROM data_local
+			WHERE data_template_id = ?',
+			array(get_request_var('id')));
+	} else {
+		$readOnly = false;
+	}
+
+	if (!$isSNMPget && !$readOnly) {
 		html_start_box(__('Data Source Item [%s]', (isset($template_rrd) ? html_escape($template_rrd['data_source_name']) : '')), '100%', true, '0', 'center', (!isempty_request_var('id') ? 'data_templates.php?action=rrd_add&id=' . get_request_var('id'):''), __('New'));
 	} else {
 		html_start_box(__('Data Source Item [%s]', (isset($template_rrd) ? html_escape($template_rrd['data_source_name']) : '')), '100%', true, '0', 'center', '', '');
@@ -779,6 +807,44 @@ function template_edit() {
 	}
 
 	form_save_button('data_templates.php', 'return');
+
+	?>
+	<script type='text/javascript'>
+
+	var readOnly = <?php print $readOnly ? 'true':'false';?>;
+
+	$(function() {
+		if (readOnly) {
+			// Data Source
+			$('#data_input_id').prop('disabled', true).addClass('ui-state-disabled');
+			$('#t_data_input_id').prop('disabled', true).addClass('ui-state-disabled');
+
+			if ($('#data_input_id').selectmenu('instance')) {
+				$('#data_input_id').selectmenu('disable');
+			}
+
+			// Data source attributes
+			$('#data_source_name').prop('disabled', true).addClass('ui-state-disabled');
+			$('#t_data_source_name').prop('disabled', true).addClass('ui-state-disabled');
+			$('#data_source_type_id').prop('disabled', true).addClass('ui-state-disabled');
+			$('#t_data_source_type_id').prop('disabled', true).addClass('ui-state-disabled');
+
+			// Custom Data
+			$('#value_index_type').prop('disabled', true).addClass('ui-state-disabled');
+			$('#t_value_index_type').prop('disabled', true).addClass('ui-state-disabled');
+			$('#value_index_value').prop('disabled', true).addClass('ui-state-disabled');
+			$('#t_value_index_value').prop('disabled', true).addClass('ui-state-disabled');
+			$('#value_output_type').prop('disabled', true).addClass('ui-state-disabled');
+			$('#t_value_output_type').prop('disabled', true).addClass('ui-state-disabled');
+
+			if ($('#data_source_type_id').selectmenu('instance')) {
+				$('#data_source_type_id').selectmenu('disable');
+			}
+		}
+	});
+
+	</script>
+	<?php
 }
 
 function template() {
@@ -970,7 +1036,7 @@ function template() {
 	$sql_order = get_order_string();
 	$sql_limit = ' LIMIT ' . ($rows*(get_request_var('page')-1)) . ',' . $rows;
 
-	$template_list = db_fetch_assoc("SELECT dt.id, dt.name,
+	$template_list_sql = "SELECT dt.id, dt.name,
 		di.name AS data_input_method, dtd.active AS active, dsp.name AS profile_name,
 		SUM(CASE WHEN dtd.local_data_id>0 THEN 1 ELSE 0 END) AS data_sources
 		FROM data_template AS dt
@@ -984,7 +1050,8 @@ function template() {
 		GROUP BY dt.id
 		$sql_having
 		$sql_order
-		$sql_limit");
+		$sql_limit";
+	$template_list = db_fetch_assoc($template_list_sql);
 
 	$nav = html_nav_bar('data_templates.php?filter=' . get_request_var('filter'), MAX_DISPLAY_PAGES, get_request_var('page'), $rows, $total_rows, 7, __('Data Templates'), 'page', 'main');
 
@@ -1014,11 +1081,15 @@ function template() {
 				$disabled = false;
 			}
 
+			$ds_url = 'data_sources.php?reset=true&template_id=' . $template['id'];
+			if (get_request_var('profile') != '-1') {
+				$ds_url .= '&profile=' . get_request_var('profile');
+			}
 			form_alternate_row('line' . $template['id'], true, $disabled);
 			form_selectable_cell(filter_value($template['name'], get_request_var('filter'), 'data_templates.php?action=template_edit&id=' . $template['id']), $template['id']);
 			form_selectable_cell($template['id'], $template['id'], '', 'right');
 			form_selectable_cell($disabled ? __('No'):__('Yes'), $template['id'], '', 'right');
-			form_selectable_cell('<a class="linkEditMain" href="' . html_escape('data_sources.php?reset=true&template_id=' . $template['id']) . '">' . number_format_i18n($template['data_sources']) . '</a>', $template['id'], '', 'right');
+			form_selectable_cell('<a class="linkEditMain" href="' . html_escape($ds_url) . '">' . number_format_i18n($template['data_sources']) . '</a>', $template['id'], '', 'right');
 			form_selectable_cell((empty($template['data_input_method']) ? '<em>' . __('None') .'</em>': html_escape($template['data_input_method'])), $template['id']);
 			form_selectable_cell((empty($template['profile_name']) ? __('External'):html_escape($template['profile_name'])), $template['id']);
 			form_selectable_cell((($template['active'] == 'on') ? __('Active'):__('Disabled')), $template['id']);
