@@ -29,6 +29,7 @@ include_once('./lib/api_data_source.php');
 include_once('./lib/api_graph.php');
 include_once('./lib/api_tree.php');
 include_once('./lib/data_query.php');
+include_once('./lib/graphs.php');
 include_once('./lib/html_graph.php');
 include_once('./lib/html_form_template.php');
 include_once('./lib/html_tree.php');
@@ -148,7 +149,7 @@ function get_ajax_graph_items() {
 		FROM (SELECT data_template_rrd.id AS id,
 			CONCAT_WS('',
 			CASE
-			WHEN host.description IS NULL THEN 'No Device - '
+			WHEN host.description IS NULL THEN '" . __esc('No Device - ') . "'
 			WHEN host.description IS NOT NULL THEN ''
 			END,
 			data_template_data.name_cache,' (',data_template_rrd.data_source_name,')') AS name
@@ -163,7 +164,7 @@ function get_ajax_graph_items() {
 		FROM (SELECT data_template_rrd.id AS id,
 			CONCAT_WS('',
 			CASE
-			WHEN host.description IS NULL THEN 'No Device - '
+			WHEN host.description IS NULL THEN '" . __esc('No Device - ') . "'
 			WHEN host.description IS NOT NULL THEN ''
 			END,
 			data_template_data.name_cache,' (',data_template_rrd.data_source_name,')') AS name
@@ -417,44 +418,6 @@ function form_save() {
     The "actions" function
    ------------------------ */
 
-function get_current_graph_template_details($local_graph_id) {
-	$graph_local = db_fetch_row_prepared('SELECT *
-		FROM graph_local
-		WHERE id = ?',
-		array($local_graph_id));
-
-	if (!cacti_sizeof($graph_local) || $graph_local['graph_template_id'] == 0) {
-		return array('id' => 0, 'name' => __('Not Templated'), 'source' => 0);
-	} elseif ($graph_local['snmp_query_id'] > 0) {
-		$detail = db_fetch_row_prepared('SELECT sqg.id, sqg.name
-			FROM snmp_query_graph AS sqg
-			INNER JOIN graph_local AS gl
-			ON gl.snmp_query_graph_id=sqg.id
-			AND gl.snmp_query_id=sqg.snmp_query_id
-			WHERE gl.id = ?',
-			array($local_graph_id));
-
-		if (cacti_sizeof($detail)) {
-			return array('id' => $detail['id'], 'name' => $detail['name'], 'source' => 1);
-		} else {
-			return array('id' => 0, 'name' => __('Not Found'), 'source' => 1);
-		}
-	} else {
-		$detail = db_fetch_row_prepared('SELECT gt.id, gt.name
-			FROM graph_templates AS gt
-			INNER JOIN graph_local AS gl
-			ON gl.graph_template_id=gt.id
-			WHERE gl.id = ?',
-			array($local_graph_id));
-
-		if (cacti_sizeof($detail)) {
-			return array('id' => $detail['id'], 'name' => $detail['name'], 'source' => 2);
-		} else {
-			return array('id' => 0, 'name' => __('Not Found'), 'source' => 2);
-		}
-	}
-}
-
 function get_current_graph_template($local_graph_id) {
 	$graph_local = db_fetch_row_prepared('SELECT *
 		FROM graph_local
@@ -746,21 +709,27 @@ function form_actions() {
 				$attribs['total_items']     = array();
 				$attribs['graph_item_types']= array();
 				$attribs['cdefs']           = array();
+
 				foreach ($aggregate_graph_items as $item) {
-					if (isset($item['color_template']) && $item['color_template'] > 0)
+					if (isset($item['color_template']) && $item['color_template'] > 0) {
 						$attribs['color_templates'][ $item['sequence'] ] = $item['color_template'];
+					}
 
-					if (isset($item['item_skip']) && $item['item_skip'] == 'on')
+					if (isset($item['item_skip']) && $item['item_skip'] == 'on') {
 						$attribs['skipped_items'][ $item['sequence'] ] = $item['sequence'];
+					}
 
-					if (isset($item['item_total']) && $item['item_total'] == 'on')
+					if (isset($item['item_total']) && $item['item_total'] == 'on') {
 						$attribs['total_items'][ $item['sequence'] ] = $item['sequence'];
+					}
 
-					if (isset($item['cdef_id']) && isset($item['t_cdef_id']) && $item['t_cdef_id'] == 'on')
+					if (isset($item['cdef_id']) && isset($item['t_cdef_id']) && $item['t_cdef_id'] == 'on') {
 						$attribs['cdefs'][ $item['sequence'] ] = $item['cdef_id'];
+					}
 
-					if (isset($item['graph_type_id']) && isset($item['t_graph_type_id']) && $item['t_graph_type_id'] == 'on')
+					if (isset($item['graph_type_id']) && isset($item['t_graph_type_id']) && $item['t_graph_type_id'] == 'on') {
 						$attribs['graph_item_types'][ $item['sequence'] ] = $item['graph_type_id'];
+					}
 				}
 
 				/* create actual graph items */
@@ -769,7 +738,7 @@ function form_actions() {
 				header("Location: aggregate_graphs.php?header=false&action=edit&tab=details&id=$local_graph_id");
 				exit;
 			} elseif (get_request_var('drp_action') == '8') { // automation
-				cacti_log('automation_graph_action_execute called: ' . $action, true, 'AUTM8 TRACE', POLLER_VERBOSITY_MEDIUM);
+				cacti_log('automation_graph_action_execute called: ' . get_request_var('drp_action'), true, 'AUTM8 TRACE', POLLER_VERBOSITY_MEDIUM);
 
 				/* work on all selected graphs */
 				for ($i=0;($i<cacti_count($selected_items));$i++) {
@@ -909,9 +878,19 @@ function form_actions() {
 				print '</ul></div><br>';
 
 				print '<span class="nowrap">';
-				form_radio_button('delete_type', '2', '2', __('Delete all Data Source(s) referenced by these Graph(s) that are not in use elsewhere.'), '1');
+
+				$ds_preselected_delete = read_config_option('ds_preselected_delete');
+				if ($ds_preselected_delete == 'on') {
+	                                $delete_radio_button_1_state = '2';
+                                	$delete_radio_button_2_state = '1';
+				} else {
+					$delete_radio_button_1_state = '1';
+					$delete_radio_button_2_state = '2';
+				}
+
+				form_radio_button('delete_type', '2', $delete_radio_button_1_state , __('Delete all Data Source(s) referenced by these Graph(s) that are not in use elsewhere.'), '1');
 				print '<br>';
-				form_radio_button('delete_type', '2', '1', __('Leave the Data Source(s) untouched.'), '1');
+				form_radio_button('delete_type', '2', $delete_radio_button_2_state , __('Leave the Data Source(s) untouched.'), '1');
 				print '<br>';
 				print '</span>';
 				print '</td></tr>';
@@ -1345,8 +1324,14 @@ function graph_edit() {
 			WHERE local_graph_id = ?',
 			array(get_request_var('id')));
 
+	        $auto_unlock = read_config_option('graphs_auto_unlock');
+
 		if (get_request_var('id') != $_SESSION['sess_graph_lock_id'] && !empty($local_graph_template_graph_id)) {
-			$locked = true;
+			if ($auto_unlock == 'on') {
+                        	$locked = false;
+                        } else {
+	                        $locked = true;
+                        }
 			$_SESSION['sess_graph_locked'] = $locked;
 		} elseif (empty($local_graph_template_graph_id)) {
 			$locked = false;
@@ -1354,7 +1339,11 @@ function graph_edit() {
 		} elseif (isset($_SESSION['sess_graph_locked'])) {
 			$locked = $_SESSION['sess_graph_locked'];
 		} else {
-			$locked = true;
+			if ($auto_unlock == 'on') {
+				$locked = false;
+			} else {
+				$locked = true;
+			}
 			$_SESSION['sess_graph_locked'] = $locked;
 		}
 
@@ -1753,6 +1742,17 @@ function validate_graph_request_vars() {
 			'options' => array('options' => array('regexp' => '(cg_[0-9]|dq_[0-9]|[\-0-9])')),
 			'pageset' => true,
 			'default' => '-1'
+			),
+		'custom' => array(
+			'filter' => FILTER_VALIDATE_REGEXP,
+			'options' => array('options' => array('regexp' => '(true|false)')),
+			'pageset' => true,
+			'default' => ''
+			),
+		'local_graph_ids' => array(
+			'filter' => FILTER_VALIDATE_IS_NUMERIC_LIST,
+			'pageset' => true,
+			'default' => ''
 			)
 	);
 
@@ -1761,7 +1761,7 @@ function validate_graph_request_vars() {
 }
 
 function graph_management() {
-	global $graph_actions, $item_rows, $config;
+	global $graph_actions, $graph_sources, $item_rows, $config;
 
 	if (get_request_var('rows') == -1) {
 		$rows = read_config_option('num_rows_table');
@@ -1813,7 +1813,18 @@ function graph_management() {
 		$add_url = '';
 	}
 
-	html_start_box(__('Graph Management'), '100%', '', '3', 'center', $add_url);
+	if (get_request_var('local_graph_ids') != '') {
+		$header = __('Graph Management [ Custom Graphs List Applied - Clear to Reset ]');
+	} elseif (get_request_var('host_id') == -1) {
+		$header = __('Graph Management [ All Devices ]');
+	} elseif (get_request_var('host_id') == 0) {
+		$header = __('Graph Management [ Non Device Based ]');
+	} else {
+		$description = db_fetch_cell_prepared('SELECT description FROM host WHERE id = ?', array(get_request_var('host_id')));
+		$header = __('Graph Management [ %s ]', $description);
+	}
+
+	html_start_box($header, '100%', '', '3', 'center', $add_url);
 
 	if (get_request_var('site_id') > 0) {
 		$host_where = 'site_id = ' . get_request_var('site_id');
@@ -1907,7 +1918,8 @@ function graph_management() {
 	$sql_where = '';
 	if (get_request_var('rfilter') != '') {
 		$sql_where = " WHERE (gtg.title_cache RLIKE '" . get_request_var('rfilter') . "'" .
-			" OR gt.name RLIKE '" . get_request_var('rfilter') . "')";
+			" OR gt.name RLIKE '" . get_request_var('rfilter') . "'" .
+			" OR gl.id = '" . get_request_var('rfilter') . "')";
 	}
 
 	if (get_request_var('host_id') == '-1') {
@@ -1939,6 +1951,10 @@ function graph_management() {
 		}
 	}
 
+	if (get_request_var('local_graph_ids') != '') {
+		$sql_where .= ($sql_where != '' ? ' AND ':'WHERE ') . ' gl.id IN(' . get_request_var('local_graph_ids') . ')';
+	}
+
 	if (get_request_var('orphans') == 'true') {
 		$orphan_where = ' AND graph_type_id IN (' .
 			GRAPH_ITEM_TYPE_LINE1     . ', ' .
@@ -1960,7 +1976,7 @@ function graph_management() {
 	$total_rows = db_fetch_cell("SELECT
 		COUNT(gtg.id)
 		FROM graph_local AS gl
-		INNER JOIN graph_templates_graph AS gtg
+		LEFT JOIN graph_templates_graph AS gtg
 		ON gl.id=gtg.local_graph_id
 		LEFT JOIN graph_templates AS gt
 		ON gl.graph_template_id=gt.id
@@ -1975,11 +1991,11 @@ function graph_management() {
 	$sql_order = get_order_string();
 	$sql_limit = ' LIMIT ' . ($rows*(get_request_var('page')-1)) . ',' . $rows;
 
-	$graph_list = db_fetch_assoc("SELECT gtg.id, gtg.local_graph_id, gtg.height, gtg.width,
-		gtg.title_cache, gt.name, gl.host_id,
-		IF(gl.graph_template_id=0, 0, IF(gl.snmp_query_id=0, 2, 1)) AS source
+	$graph_list = db_fetch_assoc("SELECT gtg.id, gl.id AS local_graph_id,
+		gtg.height, gtg.width, gtg.title_cache, gt.name, gl.host_id,
+		IF(gl.graph_template_id=0, 0, IF(gl.snmp_query_id=0, 2, 1)) AS graph_source
 		FROM graph_local AS gl
-		INNER JOIN graph_templates_graph AS gtg
+		LEFT JOIN graph_templates_graph AS gtg
 		ON gl.id=gtg.local_graph_id
 		LEFT JOIN graph_templates AS gt
 		ON gl.graph_template_id=gt.id
@@ -2001,12 +2017,6 @@ function graph_management() {
 
 	html_start_box('', '100%', '', '3', 'center', '');
 
-	$sources = array(
-		0 => __('Not Templated'),
-		1 => __('Data Query'),
-		2 => __('Template')
-	);
-
 	$display_text = array(
 		'title_cache' => array(
 			'display' => __('Graph Name'),
@@ -2020,15 +2030,15 @@ function graph_management() {
 			'sort'    => 'ASC',
 			'tip'     => __('The internal database ID for this Graph.  Useful when performing automation or debugging.')
 		),
-		'source' => array(
+		'nosort_source' => array(
 			'display' => __('Source Type'),
-			'align'   => 'right',
+			'align'   => 'center',
 			'sort'    => 'ASC',
 			'tip'     => __('The underlying source that this Graph was based upon.')
 		),
-		'name' => array(
+		'nosort_name' => array(
 			'display' => __('Source Name'),
-			'align'   => 'right',
+			'align'   => 'left',
 			'sort'    => 'ASC',
 			'tip'     => __('The Graph Template or Data Query that this Graph was based upon.')
 		),
@@ -2046,23 +2056,25 @@ function graph_management() {
 	if (cacti_sizeof($graph_list)) {
 		foreach ($graph_list as $graph) {
 			/* we're escaping strings here, so no need to escape them on form_selectable_cell */
-			$template_details = get_current_graph_template_details($graph['local_graph_id']);
+			$template_details = get_graph_template_details($graph['local_graph_id']);
 
-			if ($template_details['id'] > 0) {
-				if ($template_details['source'] == 1) { // Data Query
-					$url = $config['url_path'] . 'data_queries.php?action=item_edit&id=' . $template_details['id'];
-				} else { // Graph Template
-					$url = $config['url_path'] . 'graph_templates.php?action=template_edit&id=' . $template_details['id'];
-				}
-			} else {
-				$url = '';
+			if (isset($template_details['graph_name'])) {
+				$graph['name'] = $template_details['graph_name'];
+			}
+
+			if (isset($template_details['graph_description'])) {
+				$graph['description'] = $template_details['graph_description'];
+			}
+
+			if (empty($graph['title_cache'])) {
+				$graph['title_cache'] = __('Empty Graph');
 			}
 
 			form_alternate_row('line' . $graph['local_graph_id'], true);
 			form_selectable_cell(filter_value(title_trim($graph['title_cache'], read_config_option('max_title_length')), get_request_var('rfilter'), 'graphs.php?action=graph_edit&id=' . $graph['local_graph_id']), $graph['local_graph_id']);
 			form_selectable_cell($graph['local_graph_id'], $graph['local_graph_id'], '', 'right');
-			form_selectable_cell(filter_value($sources[$graph['source']], get_request_var('rfilter')), $graph['local_graph_id'], '', 'right');
-			form_selectable_cell(filter_value($template_details['name'], get_request_var('rfilter'), $url), $graph['local_graph_id'], '', 'right');
+			form_selectable_cell(filter_value($graph_sources[$graph['graph_source']], get_request_var('rfilter')), $graph['local_graph_id'], '', 'center');
+			form_selectable_cell(filter_value($template_details['name'], get_request_var('rfilter'), $template_details['url']), $graph['local_graph_id'], '', 'left');
 			form_selectable_ecell($graph['height'] . 'x' . $graph['width'], $graph['local_graph_id'], '', 'right');
 			form_checkbox_cell($graph['title_cache'], $graph['local_graph_id']);
 			form_end_row();
