@@ -663,14 +663,14 @@ function host_edit() {
 						<a id='dbghide' class='fa fa-times' href='#'><?php print __('Hide');?></a>
 					</span>
 				</div>
+				<table class='cactiTable' id='clipboardData<?php print $dbg_copy_uid;?>'>
+					<tr class='tableRow'>
+						<td class='debug'>
+							<span><?php print debug_log_return('data_query');?></span>
+						</td>
+					</tr>
+				</table>
 			</div>
-			<table class='cactiTable' id='clipboardData<?php print $dbg_copy_uid;?>'>
-				<tr class='tableRow'>
-					<td class='debug'>
-						<span><?php print debug_log_return('data_query');?></span>
-					</td>
-				</tr>
-			</table>
 		</div>
 		<?php
 	}
@@ -1280,7 +1280,9 @@ function host_validate_vars() {
 function get_device_records(&$total_rows, $rows) {
 	/* form the 'where' clause for our main sql query */
 	if (get_request_var('filter') != '') {
-		$sql_where = "WHERE (deleted = '' AND (host.hostname LIKE '%" . get_request_var('filter') . "%' OR host.description LIKE '%" . get_request_var('filter') . "%' OR host.id LIKE '%" . get_request_var('filter') . "%'))";
+		$sql_where = "WHERE (deleted = '' AND (host.hostname LIKE '%" . get_request_var('filter') . "%'" .
+			" OR host.description LIKE '%" . get_request_var('filter') . "%'" .
+			" OR host.id = '" . get_request_var('filter') . "'))";
 	} else {
 		$sql_where = "WHERE deleted = ''";
 	}
