@@ -1,66 +1,31 @@
 // Host Autocomplete Magic
 var pageName = basename($(location).attr('pathname'));
 
-function myKeepWindowSize() {
-	$(window).resize(function (event) {
-		waitForFinalEvent(function(){
-			/* close open dropdown menues first off */
-			$('.dropdownMenu > ul').hide();
-
-			/* check visibility of all tabs */
-			$('#submenu-ellipsis').empty();
-			$('.maintabs nav ul li a').each(function() {
-				id = $(this).attr('id');
-				if ( $(this).offset().top !== 0 ) {
-					if ( $('#' + id + '-ellipsis').length == 0 ) {
-						var str = $(this).parent().html();
-						var str2 = str.replace( id , id + '-ellipsis');
-						$('#submenu-ellipsis').prepend('<li>' + str2 + '</li>');
-						$('#'+ id + '-ellipsis').css('visibility','');
-						$(this).css('visibility', 'hidden');
-					}
-				} else {
-					$('#' + id + '-ellipsis').parent().remove();
-					$(this).css('visibility', 'visible');
-				}
-			});
-
-			if ($('#submenu-ellipsis li').length == 0) {
-				$('.ellipsis').hide(0);
-			} else {
-				$('.ellipsis').show(0);
-			}
-		}, 300, 'resize-content');
-	});
-}
-
 function themeReady() {
 	var pageName = basename($(location).attr('pathname'));
 	var hostTimer = false;
 	var clickTimeout = false;
 	var hostOpen = false;
 
-	myKeepWindowSize();
-
 	// Setup the navigation menu
 	setMenuVisibility();
 
 	$('#navigation_right').unbind().scroll(function (event) {
         var scroll_position_x = $('#navigation_right').scrollLeft();
         var scroll_position_y = $('#navigation_right').scrollTop();
-        $('.bottom_scroll_up').css({'color': ((scroll_position_x == 0 & scroll_position_y == 0 ) ? '' : '#93CEFF') });
+        $('.bottom_scroll_up').css({'color': ((scroll_position_x == 0 & scroll_position_y == 0) ? '' : '#93CEFF') });
     });
 
 	// Add nice search filter to filters
-	if ($('input[id="filter"]').length > 0) {
+	if ($('input[id="filter"]').length > 0 && $('input[id="filter"] > i[class="fa fa-search filter"]').length < 1) {
 		$('input[id="filter"]').after("<i class='fa fa-search filter'/>").attr('autocomplete', 'off').attr('placeholder', searchFilter).parent('td').css('white-space', 'nowrap');
 	}
 
-	if ($('input[id="filterd"]').length > 0) {
+	if ($('input[id="filterd"]').length > 0 && $('input[id="filterd"] > i[class="fa fa-search filter"]').length < 1) {
 		$('input[id="filterd"]').after("<i class='fa fa-search filter'/>").attr('autocomplete', 'off').attr('placeholder', searchFilter).parent('td').css('white-space', 'nowrap');
 	}
 
-	if ($('input[id="rfilter"]').length > 0) {
+	if ($('input[id="rfilter"]').length > 0 && $('input[id="rfilter"] > i[class="fa fa-search filter"]').length < 1) {
 		$('input[id="rfilter"]').after("<i class='fa fa-search filter'/>").attr('autocomplete', 'off').attr('placeholder', searchRFilter).parent('td').css('white-space', 'nowrap');
 	}
 
@@ -74,65 +39,49 @@ function themeReady() {
 	$('.cactiLoginLogo').html("<i class='fa fa-sun-o'/>");
 	$('.cactiLogoutLogo').html("<i class='fa fa-sun-o'/>");
 
-
 	/* clean up the navigation menu */
 	$('.cactiConsoleNavigationArea').find('#menu').appendTo($('.cactiConsoleNavigationArea').find('#navigation'));
 	$('.cactiConsoleNavigationArea').find('#navigation > table').remove();
 
-	/* 'ellipsis' menu in the middle */
-	if ($('.ellipsis').length == 0) {
-		$('<div class="maintabs ellipsis">'
-			+'<nav><ul>'
-				+'<li class="maintabs-submenu">'
-					+'<a class="submenu-ellipsis" href="#"><i class="fa fa-caret-down"></i></a></li>'
-			+'</ul></nav>'
-		+'</div>').insertAfter('.maintabs');
-	}
-	$('<div class="dropdownMenu">'
-		+'<ul id="submenu-ellipsis" class="submenuoptions" style="display:none;">'
-		+'</ul>'
-	+'</div>').appendTo('body');
-
 	/* Hey - No footer available ? */
 	if ($('#cactiPageBottom').length == 0) {
 		$('<div id="cactiPageBottom" class="cactiPageBottom"><span class="cactiVersion">Version '+ cactiVersion +'</span><a class="bottom_scroll_up action-icon-user" href="#"><i class="fa fa-arrow-circle-up"></i></a></div>').insertAfter('#cactiContent');
 	}
-	/* Console? Nope! */
-	submenu_counter = 10;
 
-	$('.maintabs nav ul li a').each( function() {
+	$('.maintabs nav ul li a.lefttab').each( function() {
 		id = $(this).attr('id');
-		if ( id == 'maintab-anchor-console') {
-			$(this).html("<i class='fa fa-sun-o'/>");
-		} else if ( id == 'maintab-anchor-graphs' && $(this).parent().hasClass('maintabs-has-submenu') == 0 ) {
-			submenu_counter++;
+		if (id == 'tab-graphs' && $(this).parent().hasClass('maintabs-has-submenu') == 0) {
 			$(this).parent().addClass('maintabs-has-submenu');
-			$('<li class="maintabs-submenu"><a class="submenu-' + submenu_counter + '" href="#"><i class="fa fa-caret-down"></i></a></li>').insertAfter( $(this) );
 			$('<div class="dropdownMenu">'
-				+'<ul id="submenu-' + submenu_counter + '" class="submenuoptions" style="display:none;">'
+				+'<ul id="submenu-tab-graphs" class="submenuoptions" style="display:none;">'
 					+'<li><a href="'+urlPath+'graph_view.php?action=tree"><span>'+treeView+'</span></a></li>'
 					+'<li><a href="'+urlPath+'graph_view.php?action=list"><span>'+listView+'</span></a></li>'
 					+'<li><a href="'+urlPath+'graph_view.php?action=preview"><span>'+previewView+'</span></a></li>'
 				+'</ul>'
 			+'</div>').appendTo('body');
-		} else {
-			/* plugin stuff here ? */
 		}
 	});
 
 	/* user menu on the right ... */
 	if ($('.usertabs').length == 0) {
+		$('#userDocumentation').remove();
+		$('#userCommunity').remove();
+		$('.menuHr').remove();
 		$('<div class="maintabs usertabs">'
 			+'<nav><ul>'
-				+'<li class="usertabs-submenu"><a class="submenu-user-help" href="#"><i class="fa fa-question"></i></a></li>'
+				+'<li><a id="menu-user-help" class="usertabs-submenu" href="#"><i class="fa fa-question"></i></a></li>'
 				+'<li class="action-icon-user"><a class="pic" href="#"><i class="fa fa-user"></i></a></li>'
 			+'</ul></nav>'
-		+'</div>').insertAfter('.ellipsis');
+		+'</div>').insertAfter('.maintabs');
+
 		$('<div class="dropdownMenu">'
 			+'<ul id="submenu-user-help" class="submenuoptions right" style="display:none;">'
-				+'<li><a href="http://www.cacti.net" target="_blank"><span>'+cactiHome+'</span></a></li>'
+				+'<li><a href="https://www.cacti.net" target="_blank"><span>'+cactiHome+'</span></a></li>'
 				+'<li><a href="https://github.com/cacti" target="_blank"><span>'+cactiProjectPage+'</span></a></li>'
-				+'<li><a href="http://forums.cacti.net/" target="_blank"><span>'+cactiCommunityForum+'</span></a></li>'
+				+'<li><hr class="menu"></li>'
+				+'<li><a href="https://forums.cacti.net/" target="_blank"><span>'+cactiCommunityForum+'</span></a></li>'
+				+'<li><a href="https://github.com/Cacti/documentation/blob/develop/README.md" target="_blank"><span>'+cactiDocumentation+'</span></a></li>'
+				+'<li><hr class="menu"></li>'
 				+'<li><a href="https://github.com/Cacti/cacti/issues/new" target="_blank"><span>'+reportABug+'</span></a></li>'
 				+'<li><a href="'+urlPath+'about.php"><span>'+aboutCacti+'</span></a></li>'
 			+'</ul>'
@@ -144,17 +93,16 @@ function themeReady() {
 	/* User Menu */
 	$('.menuoptions').parent().appendTo('body');
 
-	$(window).trigger('resize');
-
 	$('.action-icon-user').unbind().click(function(event) {
 		event.preventDefault();
 
-		if ( $('.menuoptions').is(':visible') === false ) {
+		if ($('.menuoptions').is(':visible') === false) {
 			$('.submenuoptions').stop().slideUp(120);
 			$('.menuoptions').stop().slideDown(120);
 		} else {
 			$('.menuoptions').stop().slideUp(120);
 		}
+
 		return false;
 	});
 
@@ -163,51 +111,15 @@ function themeReady() {
 		$('#navigation_right').animate({ scrollLeft:0, scrollTop: 0 }, 1000, 'easeInOutQuart');
 	});
 
-	$('.maintabs-submenu, .usertabs-submenu').unbind('click').click(function(event) {
-		event.preventDefault();
-
-		submenu_index = $(this).children('a:first').attr('class');
-		submenu = $('#'+submenu_index);
-
-		if ( submenu.is(':visible') === false ) {
-			/* close other drop down menus first */
-			$('.submenuoptions').stop().slideUp(120);
-			$('.menuoptions').stop().slideUp(120);
-			/* re-position */
-			position = $(this).parent('.maintabs-has-submenu').position();
-			if (!position) {
-				position = $(this).position();
-				submenu.css({'left':position.left - parseInt(submenu.outerWidth()) + parseInt($(this).outerWidth()) }).slideDown(120);
-			} else {
-				/* move dd to the left */
-				submenu.css({'left':position.left}).slideDown(120);
-			}
-		} else {
-			submenu.slideUp(120);
-		}
-
-		return false;
-	});
-
-	$('.submenuoptions').mouseenter(function(data) {
-		clearTimeout(userMenuTimer);
-	}).mouseleave(function(data) {
-		if ($('.submenuoptions').is(':visible')) {
-			userMenuTimer = setTimeout(function() {$('.submenuoptions').stop().slideUp(120);}, 1000);
-		} else {
-			clearTimeout(userMenuOpenTimer);
-		}
-	});
-
 	/* Highlight sortable table columns */
-	$('.tableHeader th').has('i.fa-unsorted').removeClass('tableHeaderColumnHover tableHeaderColumnSelected');
-	$('.tableHeader th').has('i.fa-sort-asc').addClass('tableHeaderColumnSelected');
-	$('.tableHeader th').has('i.fa-sort-desc').addClass('tableHeaderColumnSelected');
-	$('.tableHeader th').has('i.fa-unsorted').hover(
+	$('.tableHeader th').has('i.fa-sort').removeClass('tableHeaderColumnHover tableHeaderColumnSelected');
+	$('.tableHeader th').has('i.fa-sort-up').addClass('tableHeaderColumnSelected');
+	$('.tableHeader th').has('i.fa-sort-down').addClass('tableHeaderColumnSelected');
+	$('.tableHeader th').has('i.fa-sort').hover(
 		function() {
-			$( this ).addClass("tableHeaderColumnHover" );
+			$(this).addClass("tableHeaderColumnHover");
 		}, function() {
-			$( this ).removeClass( "tableHeaderColumnHover" );
+			$(this).removeClass("tableHeaderColumnHover");
 		}
 	);
 
@@ -221,6 +133,7 @@ function themeReady() {
 		text=this.value;
 		setImportFile(text);
 	});
+
 	setImportFile(noFileSelected);
 
 	function setImportFile(fileText) {
@@ -231,27 +144,21 @@ function themeReady() {
 
 	$('select').not('.colordropdown').each(function() {
 		if ($(this).prop('multiple') != true) {
-			$(this).selectmenu({
-				change: function(event, ui) {
-					$(this).val(ui.item.value).change();
-				},
-				position: {
-					my: "left top",
-					at: "left bottom",
-					collision: "flip"
-				},
-			}).each(function() {
+			$(this).each(function() {
 				id = $(this).attr('id');
-				minWidth = 0;
-				$('#'+id+' > option').each(function() {
-					width=$(this).textWidth();
-					if (width > minWidth) {
-						minWidth = width;
-					}
+
+				$(this).selectmenu({
+					change: function(event, ui) {
+						$(this).val(ui.item.value).change();
+					},
+					position: {
+						my: "left top",
+						at: "left bottom",
+						collision: "flip"
+					},
+					width: 'auto'
 				});
 
-				minWidth+=80;
-				$('#'+id+'-button').css('min-width', minWidth+'px').css('max-width', '400px').css('width','');
 				$('#'+id+'-menu').css('max-height', '250px');
 			});
 		} else {
@@ -302,7 +209,7 @@ function themeReady() {
 
 		// hide the previously shown element
 		if (element.attr('id').replace('dd', '') != graphMenuElement && graphMenuElement > 0) {
-			$('#dd'+graphMenuElement).find('.iconWrapper:first').hide('slide', { direction: 'left' }, 300);
+			$('#dd'+graphMenuElement).find('.iconWrapper:first').hide(300);
 		}
 
 		clearTimeout(graphMenuTimer);
@@ -316,7 +223,7 @@ function themeReady() {
 
 	function showGraphMenu(element) {
 		element.find('.spikekillMenu').menu('disable');
-		element.find('.iconWrapper').show('slide', { direction: 'left' }, 300, function() {
+		element.find('.iconWrapper').show(300, function() {
 			graphMenuElement = element.attr('id').replace('dd', '');;
 			$(this).find('.spikekillMenu').menu('enable');
 		});
@@ -324,10 +231,12 @@ function themeReady() {
 
 	function hideGraphMenu(element) {
 		element.find('.spikekillMenu').menu('disable');
-		element.find('.iconWrapper').hide('slide', { direction: 'left' }, 300, function() {
+		element.find('.iconWrapper').hide(300, function() {
 			$(this).find('.spikekillMenu').menu('enable');
 		});
 	}
+
+	setNavigationScroll();
 }
 
 function setMenuVisibility() {
@@ -338,30 +247,31 @@ function setMenuVisibility() {
 	$('#navigation').hide();
 	$('li.menuitem').each(function() {
 		active = storage.get($(this).attr('id'));
-		if (active !== null) {
-			if (active == 'active') {
-				$(this).find('ul').attr('aria-hidden', 'false').attr('aria-expanded', 'true').show();
-				$(this).next('a').show();
-			} else {
-				$(this).find('ul').attr('aria-hidden', 'true').attr('aria-expanded', 'false').hide();
-				$(this).next('a').hide();
-			}
+		if (active !== null && active == 'active') {
+			$(this).find('ul').attr('aria-hidden', 'false').attr('aria-expanded', 'true').show();
+			$(this).next('a').show();
+		} else {
+			$(this).find('ul').attr('aria-hidden', 'true').attr('aria-expanded', 'false').hide();
+			$(this).next('a').hide();
 		}
 
 		if ($(this).find('a.selected').length) {
 			$('li.menuitem').not('#'+$(this).attr('id')).each(function() {
 				$(this).find('ul').attr('aria-hidden', 'true').attr('aria-expanded', 'false').hide();
 				$(this).next('a').hide();
+
 				storage.set($(this).closest('.menuitem').attr('id'), 'collapsed');
 			});
 
 			if ($(this).is(':hidden')) {
 				$(this).find('ul').attr('aria-hidden', 'false').attr('aria-expanded', 'true').show();
 				$(this).next('a').show();
+
 				storage.set($(this).closest('.menuitem').attr('id'), 'active');
 			}
 		}
 	});
+
 	$('#navigation').show();
 
 	// Functon to give life to the Navigation pane
@@ -370,13 +280,15 @@ function setMenuVisibility() {
 
 		id = $(this).closest('.menuitem').attr('id');
 
-		if ($(this).next().is(':visible')){
+		if ($(this).next().is(':visible')) {
 			$(this).next('ul').attr('aria-hidden', 'true').attr('aria-expanded', 'false');
-			$(this).next().slideUp( { duration: 200, easing: 'swing' } );
+			$(this).next().slideUp({ duration: 200, easing: 'swing' });
+
 			storage.set($(this).closest('.menuitem').attr('id'), 'collapsed');
 		} else {
 			$(this).next('ul').attr('aria-hidden', 'false').attr('aria-expanded', 'true');
-			$(this).next().slideToggle( { duration: 200, easing: 'swing' } );
+			$(this).next().slideToggle({ duration: 200, easing: 'swing' });
+
 			if ($(this).next().is(':visible')) {
 				storage.set($(this).closest('.menuitem').attr('id'), 'active');
 			} else {
@@ -389,8 +301,9 @@ function setMenuVisibility() {
 			id   = $(this).attr('id');
 
 			$(this).find('ul').attr('aria-hidden', 'true').attr('aria-expanded', 'false');
-			$(this).find('ul').slideUp( { duration: 200, easing: 'swing' } );
+			$(this).find('ul').slideUp({ duration: 200, easing: 'swing' });
 			storage.set($(this).attr('id'), 'collapsed');
 		});
 	});
 }
+
