@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2018 The Cacti Group                                 |
+ | Copyright (C) 2004-2019 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -467,6 +467,13 @@ function reports_item_edit() {
 			array(get_filter_request_var('item_id')));
 	}
 
+	// if a different item_type was selected, use it
+	if (isset_request_var('item_type')) {
+		if (get_filter_request_var('item_type') > 0) {
+			$report_item['item_type'] = get_request_var('item_type');
+		}
+	}
+
 	if (cacti_sizeof($report_item) || $report_item['item_type'] == REPORTS_ITEM_GRAPH) {
 		$trees           = array();
 		$branches        = array();
@@ -572,7 +579,9 @@ function reports_item_edit() {
 			);
 		}
 
-		$graphs = array_merge($graphs, $agg);
+		$graphs += $agg;
+
+		asort($graphs);
 	}
 
 	if (!isset($report_item) || $report_item['item_type'] == REPORTS_ITEM_TREE) {
@@ -783,16 +792,22 @@ function reports_item_edit() {
 	form_hidden_box('report_id', (isset($reports_item['report_id']) ? $reports_item['report_id'] : '0'), '');
 	form_hidden_box('save_component_report_item', '1', '');
 
-	echo "<table id='graphdiv' style='text-align:center;width:100%;display:none;'><tr><td class='center' id='graph'></td></tr></table>";
+	print "<table id='graphdiv' style='text-align:center;width:100%;display:none;'><tr><td class='center' id='graph'></td></tr></table>";
 
 	form_save_button(get_reports_page() . '?action=edit&tab=items&id=' . get_request_var('id'), 'return');
 
-	if (isset($item['item_type']) && $item['item_type'] == REPORTS_ITEM_GRAPH) {
+	if (isset($reports_item['item_type']) && $reports_item['item_type'] == REPORTS_ITEM_GRAPH) {
 		$timespan = array();
 		# get config option for first-day-of-the-week
 		$first_weekdayid = read_user_setting('first_weekdayid');
 		# get start/end time-since-epoch for actual time (now()) and given current-session-timespan
-		get_timespan($timespan, time(), $item['timespan'], $first_weekdayid);
+		if (isset($reports_item['timespan'])) {
+			$current_ts = $reports_item['timespan'];
+		} else {
+			$current_ts = 7;
+		}
+
+		get_timespan($timespan, time(), $current_ts, $first_weekdayid);
 	}
 
 	/* don't cache previews */
@@ -804,7 +819,6 @@ function reports_item_edit() {
 	useCss=<?php print ($report['cformat'] == 'on' ? 'true':'false');?>;
 
 	function toggle_item_type() {
-		//console.log($('#item_type').val());
 		// right bracket ')' does not come with a field
 		if ($('#item_type').val() == '<?php print REPORTS_ITEM_GRAPH;?>') {
 			$('#row_align').show();
@@ -1165,6 +1179,9 @@ function reports_edit() {
 	$report = array();
 	if (get_filter_request_var('id') > 0) {
 		$report = db_fetch_row_prepared('SELECT * FROM reports WHERE id = ?', array(get_request_var('id')));
+	}
+
+	if ($report !== false && isset($report['id'])) {
 		# reformat mailtime to human readable format
 		$report['mailtime'] = date(reports_date_time_format(), $report['mailtime']);
 		# setup header
