@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2018 The Cacti Group                                 |
+ | Copyright (C) 2004-2019 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -124,10 +124,14 @@ function exec_background($filename, $args = '', $redirect_args = '') {
 
 	if (file_exists($filename)) {
 		if ($config['cacti_server_os'] == 'win32') {
+			if (!file_escaped($filename)) {
+				$filename = cacti_escapeshellcmd($filename);
+			}
+
 			if ($redirect_args == '') {
-				pclose(popen("start \"Cactiplus\" /I \"" . $filename . "\" " . $args, 'r'));
+				pclose(popen('start "Cactiplus" /I ' . $filename . ' ' . $args, 'r'));
 			} else {
-				pclose(popen("start \"Cactiplus\" /I \"" . $filename . "\" " . $args . ' ' . $redirect_args, 'r'));
+				pclose(popen('start "Cactiplus" /I ' . $filename . ' ' . $args . ' ' . $redirect_args, 'r'));
 			}
 		} elseif ($redirect_args == '') {
 			exec($filename . ' ' . $args . ' > /dev/null 2>&1 &');
@@ -143,6 +147,14 @@ function exec_background($filename, $args = '', $redirect_args = '') {
 	}
 }
 
+function file_escaped($file) {
+	if (substr($file, 0, 1) == '"' && substr($file, -1, 1) == '"') {
+		return true;
+	}
+
+	return false;
+}
+
 /* file_exists_2gb - fail safe version of the file exists function to correct
      for errors in certain versions of php.
    @arg $filename - the name of the file to be tested. */
@@ -234,11 +246,11 @@ function update_reindex_cache($host_id, $data_query_id) {
 			 * we do NOT make use of <oid_num_indexes> or the like!
 			 * this works, even if no <oid_num_indexes> was given
 			 */
-			$assert_value = cacti_sizeof(db_fetch_assoc_prepared('SELECT ' . SQL_NO_CACHE . ' snmp_index
+			$assert_value = cacti_sizeof(db_fetch_assoc_prepared('SELECT DISTINCT ' . SQL_NO_CACHE . ' snmp_index
 				FROM host_snmp_cache
 				WHERE host_id = ?
 				AND snmp_query_id = ?
-				GROUP BY snmp_index',
+				AND snmp_index != ""',
 				array($host_id, $data_query_id)));
 
 			/* now, we have to build the (list of) commands that are later used on a recache event
@@ -569,7 +581,7 @@ function update_resource_cache($poller_id = 1) {
 	$rpath = $config['resource_path'];
 
 	$excluded_extensions = array('tar', 'gz', 'zip', 'tgz', 'ttf', 'z', 'exe', 'pack', 'swp', 'swo');
-	$excluded_dirs       = array('.git', 'log');
+	$excluded_dirs       = array('.git', 'log', '.gitattributes', '.github');
 
 	$paths = array(
 		'base'     => array('recursive' => false, 'path' => $mpath),
@@ -623,7 +635,7 @@ function update_resource_cache($poller_id = 1) {
 				if (is_dir($mpath . '/plugins/' . $path)) {
 					if (file_exists($mpath . '/plugins/' . $path . '/INFO')) {
 						$info = parse_ini_file($mpath . '/plugins/' . $path . '/INFO', true);
-						$dir_exclusions  = array('..', '.', '.git');
+						$dir_exclusions  = array('..', '.', '.git', '.github', '.gitattributes');
 						$file_exclusions = $excluded_extensions;
 
 						if (isset($info['info']['nosync'])) {
@@ -739,7 +751,7 @@ function cache_in_path($path, $type, $recursive = true) {
 	} else {
 		$spath = ltrim(trim(str_replace($config['base_path'], '', $path), '/ \\'), '/ \\');
 		$excluded_extensions = array('tar', 'gz', 'zip', 'tgz', 'ttf', 'z', 'exe', 'pack', 'swp', 'swo');
-		$excluded_dirs_files = array('.git', '.travis.yml', 'config.php', '.gitattributes');
+		$excluded_dirs_files = array('.git', '.travis.yml', '.gitattributes', '.github');
 		$pathinfo = pathinfo($path);
 
 		if (isset($pathinfo['extension'])) {
@@ -754,12 +766,17 @@ function cache_in_path($path, $type, $recursive = true) {
 			$exclude = true;
 		}
 
-		if (array_search(basename($path), $excluded_dirs_files, true) !== false) {
+		if (basename($path) == 'config.php' && strpos($path, 'plugins') !== false) {
+			// Allow replication of plugin based config.php files
+			$exclude = false;
+		} elseif (basename($path) == 'config.php') {
+			$exclude = true;
+		} elseif (array_search(basename($path), $excluded_dirs_files, true) !== false) {
 			$exclude = true;
 		}
 
 		/* exclude spurious extensions */
-		if (!$exclude && basename($path) != 'config.php') {
+		if (!$exclude) {
 			$curr_md5 = md5_file($path);
 			$last_md5 = db_fetch_cell_prepared('SELECT md5sum FROM poller_resource_cache WHERE path = ?', array($spath));
 
@@ -800,7 +817,7 @@ function update_db_from_path($path, $type, $recursive = true) {
 					if ($recursive) {
 						update_db_from_path($path . DIRECTORY_SEPARATOR . $entry, $type, $recursive);
 					}
-				} elseif (basename($path) == 'config.php') {
+				} elseif (basename($path) == 'config.php' && strpos($path, 'plugins') === false) {
 					continue;
 				} elseif (basename($path) == '.travis.yml') {
 					continue;
@@ -911,7 +928,7 @@ function resource_cache_out($type, $path) {
 				}
 
 				if (is_dir(dirname($mypath))) {
-					if ($md5sum != $e['md5sum'] && basename($e['path']) != 'config.php') {
+					if ($md5sum != $e['md5sum'] && $e['path'] != 'include/config.php') {
 						$attributes = empty($e['attributes']) ? 0 : $e['attributes'];
 						$extension = substr(strrchr($e['path'], "."), 1);
 						$exit = -1;
@@ -1012,8 +1029,10 @@ function md5sum_path($path, $recursive = true) {
 				$filemd5s[] = md5sum_path($path . DIRECTORY_SEPARATOR. $entry, $recursive);
 			} elseif (is_dir($path . DIRECTORY_SEPARATOR . $entry)) {
 				// Ignore directories who are not recursive
-			} else {
+			} elseif (is_readable($path . DIRECTORY_SEPARATOR . $entry)) {
 				$filemd5s[] = md5_file($path . DIRECTORY_SEPARATOR . $entry);
+			} else {
+				cacti_log('WARNING: Unable to read file \'' . $path . DIRECTORY_SEPARATOR . $entry . '\' into Cacti resource cache.', false, 'POLLER');
 			}
          }
     }
@@ -1120,6 +1139,7 @@ function replicate_out($remote_poller_id = 1, $class = 'all') {
 			AND name NOT LIKE "stats%"
 			AND name != "rrdtool_version"
 			AND name NOT LIKE "poller_replicate%"
+			AND name NOT LIKE "install%"
 			AND name != "poller_enabled"
 			AND name NOT LIKE "md5dirsum%"
 			UNION
@@ -1336,7 +1356,7 @@ function replicate_in() {
 		)
 	);
 
-	api_plugin_hook_function('replicate_in', $remote_poller_id);
+	api_plugin_hook_function('replicate_in');
 }
 
 function replicate_out_table($conn, &$data, $table, $remote_poller_id) {
@@ -1429,30 +1449,43 @@ function poller_push_reindex_only_data_to_main($device_id, $data_query_id) {
 	}
 }
 
-function poller_push_reindex_data_to_main($device_id = 0, $data_query_id = 0) {
+function poller_push_reindex_data_to_main($device_id = 0, $data_query_id = 0, $force = false) {
 	global $remote_db_cnn_id;
 
 	$sql_where   = '';
 	$sql_where1  = '';
 	$sql_where  .= $device_id > 0 ? 'WHERE host_id = ' . $device_id:'';
 	$sql_where1 .= $device_id > 0 ? ' AND host_id = ' . $device_id:'';
+
 	if ($data_query_id > 0) {
 		$sql_where .= ($sql_where != '' ? ' AND':'WHERE ') . ' snmp_query_id = ' . $data_query_id;
 		$sql_where1 .= ' AND snmp_query_id = ' . $data_query_id;
 	}
 
-	$min_reindex_cache = db_fetch_cell("SELECT MIN(last_updated)
-		FROM host_snmp_cache
-		$sql_where");
-
-	$recache_hosts = array_rekey(
-		db_fetch_assoc_prepared("SELECT DISTINCT host_id
+	if (!$force) {
+		// Give the snmp query upto an hour to run
+		$min_reindex_cache = db_fetch_cell("SELECT MIN(UNIX_TIMESTAMP(last_updated)-3600)
 			FROM host_snmp_cache
-			WHERE last_updated > ?
-			$sql_where1",
-			array($min_reindex_cache)),
-		'host_id', 'host_id'
-	);
+			$sql_where");
+
+		$recache_hosts = array_rekey(
+			db_fetch_assoc_prepared("SELECT DISTINCT host_id
+				FROM host_snmp_cache
+				WHERE UNIX_TIMESTAMP(last_updated) > ?
+				$sql_where1",
+				array($min_reindex_cache)),
+			'host_id', 'host_id'
+		);
+	} else {
+		$recache_hosts = array_rekey(
+			db_fetch_assoc_prepared("SELECT DISTINCT host_id
+				FROM host_snmp_cache
+				WHERE UNIX_TIMESTAMP(last_updated) > 0
+				$sql_where1",
+				array($min_reindex_cache)),
+			'host_id', 'host_id'
+		);
+	}
 
 	if (sizeof($recache_hosts)) {
 		$local_data_ids = db_fetch_assoc("SELECT *
@@ -1546,8 +1579,8 @@ function poller_recovery_flush_boost($poller_id) {
 
 	if ($poller_id > 1) {
 		if ($config['connection'] == 'recovery') {
-			$command_string = read_config_option('path_php_binary');
-			$extra_args = '-q ' . $config['base_path'] . '/poller_recovery.php';
+			$command_string = cacti_escapeshellcmd(read_config_option('path_php_binary'));
+			$extra_args = '-q ' . cacti_escapeshellarg($config['base_path'] . '/poller_recovery.php');
 			exec_background($command_string, $extra_args);
 		}
 	}
@@ -1647,7 +1680,7 @@ function poller_push_table($db_cnn, $records, $table, $ignore = false, $dupes =
 
 function should_ignore_from_replication($path) {
 	$entry = basename($path);
-	return ($entry == '.' || $entry == '..' || $entry == '.git' || $entry == '' || $entry == 'config.php');
+	return ($entry == '.' || $entry == '..' || $entry == '.git' || $entry == '');
 }
 
 function get_remote_poller_ids_from_graphs(&$graphs) {
