@@ -2,7 +2,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2018 The Cacti Group                                 |
+ | Copyright (C) 2004-2019 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -27,7 +27,7 @@
 define('MAX_RECACHE_RUNTIME', 1800);
 
 ini_set('max_runtime', '-1');
-ini_set('memory_limit', '800M');
+ini_set('memory_limit', '-1');
 
 require(__DIR__ . '/include/cli_check.php');
 require_once($config['base_path'] . '/lib/api_device.php');
@@ -172,7 +172,7 @@ if (cacti_sizeof($poller_commands)) {
 /* take time to log performance data */
 $recache = microtime(true);
 
-$recache_stats = sprintf('Poller:%i RecacheTime:%01.4f DevicesRecached:%s',	$poller_id, round($recache - $start, 4), $recached_hosts);
+$recache_stats = sprintf('Poller:%s RecacheTime:%01.4f DevicesRecached:%s',	$poller_id, round($recache - $start, 4), $recached_hosts);
 
 if ($recached_hosts > 0) {
 	cacti_log('STATS: ' . $recache_stats, true, 'RECACHE');
