@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2018 The Cacti Group                                 |
+ | Copyright (C) 2004-2019 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -142,7 +142,7 @@ function utilities_view_tech($php_info = '') {
 	/* Get table status */
 	$tables = db_fetch_assoc_prepared('SELECT *
 		FROM information_schema.tables
-		WHERE table_schema = ?', array($database_default));
+		WHERE table_schema = SCHEMA()');
 
 	/* Get poller stats */
 	$poller_item = db_fetch_assoc('SELECT action, count(action) AS total
@@ -166,9 +166,9 @@ function utilities_view_tech($php_info = '') {
 		exec(cacti_escapeshellcmd(read_config_option('path_rrdtool')), $out_array);
 		if (cacti_sizeof($out_array) > 0) {
 			if (preg_match('/^RRDtool ([0-9.]+)/', $out_array[0], $m)) {
-				preg_match('/^([0-9]+\.[0-9]+)\./', $m[1], $m2);
+				preg_match('/^([0-9]+\.[0-9]+\.[0.9]+)/', $m[1], $m2);
 				$rrdtool_release = $m[1];
-				$rrdtool_version = $m2[1];
+				$rrdtool_version = $rrdtool_release;
 			}
 		}
 	}
@@ -195,7 +195,7 @@ function utilities_view_tech($php_info = '') {
 	$spine_version = 'Unknown';
 	if ((file_exists(read_config_option('path_spine'))) && ((function_exists('is_executable')) && (is_executable(read_config_option('path_spine'))))) {
 		$out_array = array();
-		exec(read_config_option('path_spine') . ' --version', $out_array);
+		exec(cacti_escapeshellcmd(read_config_option('path_spine')) . ' --version', $out_array);
 		if (cacti_sizeof($out_array) > 0) {
 			$spine_version = $out_array[0];
 		}
@@ -690,8 +690,9 @@ function utilities_view_user_log() {
 					<td>
 						<select id='result' onChange='applyFilter()'>
 							<option value='-1'<?php if (get_request_var('result') == '-1') {?> selected<?php }?>><?php print __('Any');?></option>
-							<option value='1'<?php if (get_request_var('result') == '1') {?> selected<?php }?>><?php print __('Success - Pswd');?></option>
+							<option value='1'<?php if (get_request_var('result') == '1') {?> selected<?php }?>><?php print __('Success - Password');?></option>
 							<option value='2'<?php if (get_request_var('result') == '2') {?> selected<?php }?>><?php print __('Success - Token');?></option>
+							<option value='3'<?php if (get_request_var('result') == '3') {?> selected<?php }?>><?php print __('Success - Password Change');?></option>
 							<option value='0'<?php if (get_request_var('result') == '0') {?> selected<?php }?>><?php print __('Failed');?></option>
 						</select>
 					</td>
@@ -748,11 +749,7 @@ function utilities_view_user_log() {
 
 	/* filter by result */
 	if (get_request_var('result') != '-1') {
-		if ($sql_where != '') {
-			$sql_where .= ' AND ul.result=' . get_request_var('result');
-		} else {
-			$sql_where = 'WHERE ul.result=' . get_request_var('result');
-		}
+		$sql_where .= ($sql_where != '' ? ' AND ':'WHERE ') . ' ul.result=' . get_request_var('result');
 	}
 
 	/* filter by search string */
@@ -805,9 +802,10 @@ function utilities_view_user_log() {
 
 	html_header_sort($display_text, get_request_var('sort_column'), get_request_var('sort_direction'), 1, 'utilities.php?action=view_user_log');
 
+	$i = 0;
 	if (cacti_sizeof($user_log)) {
 		foreach ($user_log as $item) {
-			form_alternate_row('', true);
+			form_alternate_row('line' . $i, true);
 			?>
 			<td class='nowrap'>
 				<?php print filter_value($item['username'], get_request_var('filter'));?>
@@ -832,13 +830,15 @@ function utilities_view_user_log() {
 				<?php print filter_value($item['time'], get_request_var('filter'));?>
 			</td>
 			<td class='nowrap'>
-				<?php print ($item['result'] == 0 ? 'Failed':($item['result'] == 1 ? 'Success - Pswd':'Success - Token'));?>
+				<?php print ($item['result'] == 0 ? __('Failed'):($item['result'] == 1 ? __('Success - Password'):($item['result'] == 3 ? __('Success - Password Change'):__('Success - Token'))));?>
 			</td>
 			<td class='nowrap'>
 				<?php print filter_value($item['ip'], get_request_var('filter'));?>
 			</td>
 			</tr>
 			<?php
+
+			$i++;
 		}
 	}
 
@@ -1039,41 +1039,24 @@ function utilities_view_logfile() {
 						<?php print __('File');?>
 					</td>
 					<td>
-						<select id='filename'>
+						<select id='filename' onChange='applyFilter()'>
 							<?php
-							$configLogPath = read_config_option('path_cactilog');
-							$configLogBase = basename($configLogPath);
-							$selectedFile  = basename(get_nfilter_request_var('filename'));
-
-							if ($configLogPath == '') {
-								$logPath = $config['base_path'] . '/log/';
-							} else {
-								$logPath = dirname($configLogPath);
-							}
-
-							if (is_readable($logPath)) {
-								$files = scandir($logPath);
-							} else {
-								$files = array('cacti.log');
-							}
-
-							if (cacti_sizeof($files)) {
-								foreach($files as $logFile) {
-									if (in_array($logFile, array('.', '..', '.htaccess'))) {
-										continue;
-									}
-
-									if (strpos($logFile, $configLogBase) === false) {
-										continue;
-									}
+							$logFileArray = clog_get_logfiles();
 
+							if (cacti_sizeof($logFileArray)) {
+								foreach ($logFileArray as $logFile) {
 									print "<option value='" . $logFile . "'";
 
-									if ($selectedFile == $logFile) {
+									if (get_nfilter_request_var('filename') == $logFile) {
 										print ' selected';
 									}
 
-									print '>' . $logFile . "</option>\n";
+									$logParts = explode('-', $logFile);
+
+									$logDate = count($logParts) < 2 ? '' : $logParts[1] . (isset($logParts[2]) ? '-' . $logParts[2]:'');
+									$logName = $logParts[0];
+
+									print '>' . $logName . ($logDate != '' ? ' [' . substr($logDate,4) . ']':'') . "</option>\n";
 								}
 							}
 							?>
@@ -1543,7 +1526,7 @@ function utilities_view_snmp_cache() {
 			<?php print filter_value($item['name'], get_request_var('filter'));?>
 		</td>
 		<td>
-			<?php print $item['snmp_index'];?>
+			<?php print html_escape($item['snmp_index']);?>
 		</td>
 		<td>
 			<?php print filter_value($item['field_name'], get_request_var('filter'));?>
@@ -1837,7 +1820,7 @@ function utilities_view_poller_cache() {
 				</td>
 
 				<td>
-					<?php print $item['description'];?>
+					<?php print html_escape($item['description']);?>
 				</td>
 
 				<td>
@@ -1846,12 +1829,12 @@ function utilities_view_poller_cache() {
 					if ($item['snmp_version'] != 3) {
 						$details =
 							__('SNMP Version:') . ' ' . $item['snmp_version'] . ', ' .
-							__('Community:') . ' ' . $item['snmp_community'] . ', ' .
+							__('Community:') . ' ' . html_escape($item['snmp_community']) . ', ' .
 							__('OID:') . ' ' . filter_value($item['arg1'], get_request_var('filter'));
 					} else {
 						$details =
 							__('SNMP Version:') . ' ' . $item['snmp_version'] . ', ' .
-							__('User:') . ' ' . $item['snmp_username'] . ', ' . __('OID:') . ' ' . $item['arg1'];
+							__('User:') . ' ' . html_escape($item['snmp_username']) . ', ' . __('OID:') . ' ' . html_escape($item['arg1']);
 					}
 				} elseif ($item['action'] == 1) {
 						$details = __('Script:') . ' ' . filter_value($item['arg1'], get_request_var('filter'));
@@ -1860,6 +1843,7 @@ function utilities_view_poller_cache() {
 				}
 
 				print $details;
+
 				?>
 				</td>
 			</tr>
@@ -1869,7 +1853,7 @@ function utilities_view_poller_cache() {
 				<td colspan='2'>
 				</td>
 				<td>
-					<?php print __('RRD:');?> <?php print $item['rrd_path'];?>
+					<?php print __('RRD:');?> <?php print html_escape($item['rrd_path']);?>
 				</td>
 			</tr>
 			<?php
@@ -2047,8 +2031,10 @@ function boost_display_run_status() {
 
 	/* get the boost table status */
 	$boost_table_status = db_fetch_assoc("SELECT *
-		FROM INFORMATION_SCHEMA.TABLES WHERE table_schema=SCHEMA()
-		AND (table_name LIKE 'poller_output_boost_arch_%' OR table_name LIKE 'poller_output_boost')");
+		FROM INFORMATION_SCHEMA.TABLES
+		WHERE table_schema = SCHEMA()
+		AND (table_name LIKE 'poller_output_boost_arch_%'
+		OR table_name LIKE 'poller_output_boost')");
 
 	$pending_records = 0;
 	$arch_records    = 0;
